diff --git a/samples/nrf9160/lwm2m_client/prj.conf b/samples/nrf9160/lwm2m_client/prj.conf
index 188f4b896..c948978b3 100644
--- a/samples/nrf9160/lwm2m_client/prj.conf
+++ b/samples/nrf9160/lwm2m_client/prj.conf
@@ -40,6 +40,7 @@ CONFIG_LWM2M_IPSO_SUPPORT=y
 CONFIG_LWM2M_IPSO_TEMP_SENSOR_VERSION_1_1=y
 CONFIG_LWM2M_IPSO_HUMIDITY_SENSOR_VERSION_1_1=y
 CONFIG_LWM2M_IPSO_GENERIC_SENSOR_VERSION_1_1=y
+CONFIG_LWM2M_IPSO_GENERIC_SENSOR_INSTANCE_COUNT=2
 CONFIG_LWM2M_IPSO_PRESSURE_SENSOR_VERSION_1_1=y
 CONFIG_LWM2M_IPSO_PUSH_BUTTON_VERSION_1_1=y
 CONFIG_LWM2M_IPSO_ACCELEROMETER_VERSION_1_1=y
diff --git a/samples/nrf9160/lwm2m_client/src/main.c b/samples/nrf9160/lwm2m_client/src/main.c
index 522d046f2..29d40bab3 100644
--- a/samples/nrf9160/lwm2m_client/src/main.c
+++ b/samples/nrf9160/lwm2m_client/src/main.c
@@ -143,6 +143,46 @@ void send_periodically_work_handler(struct k_work *work)
 }
 #endif
 
+double sensor_value = 1.5;
+
+static void *read_cb(uint16_t obj_inst_id, uint16_t res_id, uint16_t res_inst_id, size_t *data_len)
+{
+	LOG_WRN("IN CUSTOM READ_CB");
+	LOG_WRN("obj_inst_id: %d", obj_inst_id);
+	if (obj_inst_id != 1) {
+		*data_len = 0;
+		return NULL;
+	}
+
+	sensor_value += 0.2;
+	LOG_WRN("Sensor_value: %0.2f", sensor_value);
+
+	int err = lwm2m_engine_set_float("3300/1/5700", &sensor_value);
+	if (err) {
+		LOG_ERR("Could not set custom sensor value: %d", err);
+		*data_len = 0;
+		return NULL;
+	}
+	*data_len = sizeof(sensor_value);
+	return &sensor_value;
+}
+
+static int init_resource(void)
+{
+	int err = lwm2m_engine_create_obj_inst("3300/1");
+	if (err) {
+		LOG_ERR("Could not create custom sensor object: %d", err);
+		return err;
+	}
+	err = lwm2m_engine_register_read_callback("3300/1/5700", read_cb);
+	if (err) {
+		LOG_ERR("Could not register callback for custom sensor: %d", err);
+		return err;
+	}
+	LOG_WRN("DEVICE INITED SUCCESSFULLY");
+	return 0;
+}
+
 static int lwm2m_setup(void)
 {
 #if defined(CONFIG_LWM2M_CLIENT_UTILS_DEVICE_OBJ_SUPPORT)
@@ -213,6 +253,7 @@ static int lwm2m_setup(void)
 	defined(CONFIG_LWM2M_CLIENT_UTILS_LOCATION_ASSIST_EVENTS)
 	location_event_handler_init(&client);
 #endif
+	init_resource();
 	return 0;
 }
 
